def PolynomialFeaturesTransform(data=None, object=None, accumulate=None, **generic_arguments):
    """
    DESCRIPTION:
        PolynomialFeaturesTransform() function generates a feature matrix of all polynomial
        combinations of the feature by extracting the target column, degree, bias and interaction
        information from the output of the PolynomialFeaturesFit() function.


    PARAMETERS:
        data:
            Required Argument.
            Specifies the input teradataml DataFrame.
            Types: teradataml DataFrame

        object:
            Required Argument.
            Specifies the teradataml DataFrame containing the output of generated by
            PolynomialFeaturesFit() function or the instance of PolynomialFeaturesFit.
            Types: teradataml DataFrame or PolynomialFeaturesFit

        accumulate:
            Optional Argument.
            Specifies the names of input teradataml DataFrame columns to copy to the output.
            Types: str OR list of Strings (str)

        **generic_arguments:
            Specifies the generic keyword arguments SQLE functions accept.
            Below are the generic keyword arguments:
                persist:
                    Optional Argument.
                    Specifies whether to persist the results of the function in a table or not.
                    When set to True, results are persisted in a table; otherwise, results
                    are garbage collected at the end of the session.
                    Default Value: False
                    Types: boolean

                volatile:
                    Optional Argument.
                    Specifies whether to put the results of the function in a volatile table or not.
                    When set to True, results are stored in a volatile table, otherwise not.
                    Default Value: False
                    Types: boolean

            Function allows the user to partition, hash, order or local order the input
            data. These generic arguments are available for each argument that accepts
            teradataml DataFrame as input and can be accessed as:
                * "<input_data_arg_name>_partition_column" accepts str or list of str (Strings)
                * "<input_data_arg_name>_hash_column" accepts str or list of str (Strings)
                * "<input_data_arg_name>_order_column" accepts str or list of str (Strings)
                * "local_order_<input_data_arg_name>" accepts boolean
            Note:
                These generic arguments are supported by teradataml if the underlying
                SQL Engine function supports, else an exception is raised.
    
    RETURNS:
        Instance of PolynomialFeaturesTransform.
        Output teradataml DataFrames can be accessed using attribute 
        references, such as 
        PolynomialFeaturesTransformObj.<attribute_name>.
        Output teradataml DataFrame attribute name is:
            result
    
    
    RAISES:
        TeradataMlException, TypeError, ValueError
    
    
    EXAMPLES:
        # Notes:
        #     1. Get the connection to Vantage to execute the function.
        #     2. One must import the required functions mentioned in
        #        the example from teradataml.
        #     3. Function will raise error if not supported on the Vantage
        #        user is connected to.

        # Load the example data.
        load_example_data("teradataml", ["numerics"])

        # Create teradataml DataFrame object.
        numerics = DataFrame.from_table("numerics")

        # Check the list of available analytic functions.
        display_analytic_functions()

        # Example 1: Generate feature DataFrame for all 2D polynomial combination of columns
        #            "integer_col"and "smallint_col".
        fit_obj = PolynomialFeaturesFit(data=numerics,
                                        target_columns=["integer_col", "smallint_col"],
                                        degree=2)

        # Print the result DataFrame.
        print(fit_obj.output)
        print(fit_obj.output_data)

        # Generate feature matrix. Note that teradataml DataFrame representing
        # the model is passed as input to "object".
        obj = PolynomialFeaturesTransform(data=numerics,
                                            object=fit_obj.output
                                            )

        # Print the result DataFrame.
        print(obj.result)

        # Example 2: Generate feature matrix. Note that model is passed as instance of
        #            PolynomialFeaturesFit to "object".
        obj1 = PolynomialFeaturesTransform(data=numerics,
                                           object=fit_obj
                                           )

        # Print the result DataFrame.
        print(obj1.result)
    """
